@@ -18,7 +18,7 @@ class PaintedObject(PositionedObject):
     def __init__(
         self,
         pos: PointDef,
-        parent: Optional[PositionedObject] = None,
+        parent: Optional[PositionedObject],
         brush: Optional[BrushDef] = None,
         pen: Optional[PenDef] = None,
     ):
